@@ -1,7 +1,7 @@
 #!/usr/bin/python
 #
 # Urwid advanced example column calculator application
-#    Copyright (C) 2004-2006  Ian Ward
+#    Copyright (C) 2004-2007  Ian Ward
 #
 #    This library is free software; you can redistribute it and/or
 #    modify it under the terms of the GNU Lesser General Public
@@ -35,9 +35,6 @@ import urwid
 import urwid.raw_display
 import urwid.web_display
 
-try: True # old python?
-except: False, True = 0, 1
-
 # use appropriate Screen class
 if urwid.web_display.is_web_request():
 	Screen = urwid.web_display.Screen
@@ -220,9 +217,10 @@ class ParentEdit(urwid.Edit):
 			return key
 		
 
-class CellWalker:
-	def __init__(self, content ):
-		self.content = content
+class CellWalker(urwid.ListWalker):
+	def __init__(self, content):
+		self.content = urwid.MonitoredList(content)
+		self.content.modified = self._modified
 		self.focus = (0,0)
 		# everyone can share the same divider widget
 		self.div = urwid.Divider("-")
@@ -286,8 +284,8 @@ class CellWalker:
 			
 class CellColumn( urwid.WidgetWrap ):
 	def __init__(self, letter):
-		self.content = [ Cell( None ) ]
-		self.walker = CellWalker( self.content )
+		self.walker = CellWalker([Cell(None)])
+		self.content = self.walker.content
 		self.listbox = urwid.ListBox( self.walker )
 		self.set_letter( letter )
 		urwid.WidgetWrap.__init__(self, self.frame)
@@ -533,11 +531,11 @@ class HelpColumn(urwid.BoxWidget):
 			urwid.Text(["[text continues.. press ",
 			('key',"?"), " then scroll]"]), 'helpnote' )
 		self.items = [urwid.Text(x) for x in self.help_text]
-		self.listbox = urwid.ListBox( self.items )
+		self.listbox = urwid.ListBox(urwid.SimpleListWalker(self.items))
 		self.body = urwid.AttrWrap( self.listbox, 'help' )
 		self.frame = urwid.Frame( self.body, header=self.head)
 	
-	def render( self, (maxcol, maxrow), **opts ):
+	def render( self, (maxcol, maxrow), focus=False):
 		head_rows = self.head.rows( (maxcol,) )
 		if "bottom" in self.listbox.ends_visible( 
 			(maxcol, maxrow-head_rows) ):
@@ -545,7 +543,7 @@ class HelpColumn(urwid.BoxWidget):
 		else:
 			self.frame.footer = self.foot
 
-		return self.frame.render( (maxcol, maxrow), ** opts )
+		return self.frame.render( (maxcol, maxrow), focus)
 	
 	def keypress( self, size, key ):
 		return self.frame.keypress( size, key )
@@ -566,8 +564,8 @@ class CalcDisplay:
 		]
 	
 	def __init__(self):
-		self.col_list = [ HelpColumn(), CellColumn("A") ]
-		self.columns = urwid.Columns( self.col_list, 1 )
+		self.columns = urwid.Columns([HelpColumn(), CellColumn("A")], 1)
+		self.col_list = self.columns.widget_list
 		self.columns.set_focus_column( 1 )
 		self.view = urwid.AttrWrap( self.columns, 'body' )
 		self.col_link = {}
