@@ -23,6 +23,7 @@ from __future__ import nested_scopes
 
 import sys
 import re
+import os
 
 import urwid.html_fragment
 import urwid
@@ -270,9 +271,8 @@ def example_lbcont():
 				else:
 					self.items[pos+1:pos+2] = [answer]
 
-				self.listbox.set_focus( pos+2, coming_from='above' )
-				widget, pos = self.listbox.get_focus()
 				widget.set_edit_pos(0)
+				self.listbox.set_focus( pos+2, coming_from='above' )
 			else:
 				self.top.keypress( size, k )
 		# CUT HERE
@@ -800,7 +800,9 @@ http://excess.org/templayer/
 """)
 		sys.exit( 1 )
 
-	tmpl = templayer.HtmlTemplate( "tmpl_tutorial.html" )
+	tmpl = templayer.HTMLTemplate(
+		os.path.join(os.path.dirname(sys.argv[0]),
+		"tmpl_tutorial.html"))
 	sections = read_sections( tmpl )
 	code_blocks = read_example_code()
 
@@ -813,7 +815,7 @@ http://excess.org/templayer/
 		out_file = tmpl.start_file()
 		(body, toc_slots) = generate_body( tmpl, sections,
 		                                   code_blocks, results )
-		bottom = out_file.open( ** toc_slots )
+		bottom = out_file.open( version=urwid.__version__, ** toc_slots )
 		bottom.write( body )
 		out_file.close()
 
