@@ -1,7 +1,7 @@
 #!/usr/bin/python
 #
 # Urwid tour.  It slices, it dices.. 
-#    Copyright (C) 2004-2006  Ian Ward
+#    Copyright (C) 2004-2007  Ian Ward
 #
 #    This library is free software; you can redistribute it and/or
 #    modify it under the terms of the GNU Lesser General Public
@@ -27,9 +27,6 @@ import urwid
 import urwid.raw_display
 import urwid.web_display
 
-try: True # old python?
-except: False, True = 0, 1
-
 # use appropriate Screen class
 if urwid.web_display.is_web_request():
 	Screen = urwid.web_display.Screen
@@ -289,7 +286,8 @@ class TourDisplay:
 		]
 	
 	def __init__(self):
-		self.listbox = urwid.ListBox( CONTENT )
+		walker = urwid.SimpleListWalker( CONTENT )
+		self.listbox = urwid.ListBox( walker )
 		view = urwid.AttrWrap(self.listbox, 'body')
 		self.view = urwid.Frame( view, header=HEADER )
 
