@@ -32,6 +32,8 @@ class ListWalker(object):
 	
 	signals = ["modified"]
 
+	def __hash__(self): return id(self)
+
 	def _modified(self):
 		Signals.emit(self, "modified")
 	
@@ -92,6 +94,8 @@ class SimpleListWalker(MonitoredList, ListWalker):
 			raise ListWalkerError, "SimpleListWalker expecting list like object, got: "+`contents`
 		MonitoredList.__init__(self, contents)
 		self.focus = 0
+
+	def __hash__(self): return id(self)
 	
 	def _get_contents(self):
 		"""
@@ -104,7 +108,7 @@ class SimpleListWalker(MonitoredList, ListWalker):
 
 	def _modified(self):
 		if self.focus >= len(self):
-			self.focus = len(self)-1
+			self.focus = max(0, len(self)-1)
 		ListWalker._modified(self)
 	
 	def set_modified_callback(self, callback):
@@ -1290,6 +1294,8 @@ class ListBox(BoxWidget):
 		l = []
 		middle,top,bottom = self.calculate_visible( (maxcol,maxrow), 
 			focus=focus )
+		if middle is None: # empty listbox
+			return ['top','bottom']
 		trim_top, above = top
 		trim_bottom, below = bottom
 
