@@ -26,7 +26,6 @@ import escape
 
 import encodings
 import weakref
-from UserList import UserList
 
 try:
 	import str_util
@@ -958,7 +957,7 @@ def _call_modified(fn):
 		return rval
 	return call_modified_wrapper
 
-class MonitoredList(UserList):
+class MonitoredList(list):
 	def _modified(self):
 		pass
 	
@@ -968,21 +967,21 @@ class MonitoredList(UserList):
 	def __repr__(self):
 		return "%s.%s(%s)" % (self.__class__.__module__,
 			self.__class__.__name__,
-			UserList.__repr__(self))
+			list.__repr__(self))
 
-	__add__ = _call_modified(UserList.__add__)
-	__delitem__ = _call_modified(UserList.__delitem__)
-	__delslice__ = _call_modified(UserList.__delslice__)
-	__iadd__ = _call_modified(UserList.__iadd__)
-	__imul__ = _call_modified(UserList.__imul__)
-	__rmul__ = _call_modified(UserList.__rmul__)
-	__setitem__ = _call_modified(UserList.__setitem__)
-	__setslice__ = _call_modified(UserList.__setslice__)
-	append = _call_modified(UserList.append)
-	extend = _call_modified(UserList.extend)
-	insert = _call_modified(UserList.insert)
-	pop = _call_modified(UserList.pop)
-	remove = _call_modified(UserList.remove)
-	reverse = _call_modified(UserList.reverse)
-	sort = _call_modified(UserList.sort)
+	__add__ = _call_modified(list.__add__)
+	__delitem__ = _call_modified(list.__delitem__)
+	__delslice__ = _call_modified(list.__delslice__)
+	__iadd__ = _call_modified(list.__iadd__)
+	__imul__ = _call_modified(list.__imul__)
+	__rmul__ = _call_modified(list.__rmul__)
+	__setitem__ = _call_modified(list.__setitem__)
+	__setslice__ = _call_modified(list.__setslice__)
+	append = _call_modified(list.append)
+	extend = _call_modified(list.extend)
+	insert = _call_modified(list.insert)
+	pop = _call_modified(list.pop)
+	remove = _call_modified(list.remove)
+	reverse = _call_modified(list.reverse)
+	sort = _call_modified(list.sort)
 
