@@ -78,7 +78,7 @@ def cache_widget_render(cls):
 	fn = cls.render
 	def cached_render(self, size, focus=False):
 		focus = focus and not ignore_focus
-		canv = CanvasCache.fetch(self, size, focus)
+		canv = CanvasCache.fetch(self, cls, size, focus)
 		if canv:
 			return canv
 
@@ -87,7 +87,7 @@ def cache_widget_render(cls):
 		if canv.widget_info:
 			canv = CompositeCanvas(canv)
 		canv.finalize(self, size, focus)
-		CanvasCache.store(canv)
+		CanvasCache.store(cls, canv)
 		return canv
 	cached_render.original_fn = fn
 	return cached_render
@@ -135,7 +135,7 @@ def cache_widget_rows(cls):
 	fn = cls.rows
 	def cached_rows(self, size, focus=False):
 		focus = focus and not ignore_focus
-		canv = CanvasCache.fetch(self, size, focus)
+		canv = CanvasCache.fetch(self, cls, size, focus)
 		if canv:
 			return canv.rows()
 
@@ -1604,7 +1604,8 @@ class Overlay(BoxWidget):
 	
 	def keypress(self, size, key):
 		"""Pass keypress to top_w."""
-		return self.top_w.keypress( size, key)
+		return self.top_w.keypress(self.top_w_size(size,
+                       *self.calculate_padding_filler(size, True)), key)
 	
 	def get_cursor_coords(self, size):
 		"""Return cursor coords from top_w, if any."""
